=============================
Jump Detection for Even Ramps
=============================

.. warning::

    This step can only be run on evenly-spaced ramps. Using this step
    will turn off the jump detection algorithm integrated into ramp fitting.

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: romancal.jump
